@@ -4,31 +4,20 @@ from pylav.filters.utils import FilterMixin
 
 
 class LowPass(FilterMixin):
-    __slots__ = ("_smoothing", "_off", "_default")
+    __slots__ = ("_smoothing", "_default")
 
     def __init__(self, smoothing: float = None):
         super().__init__()
         self.smoothing = smoothing
-        self.off = smoothing is None
 
     def to_dict(self) -> dict[str, float | bool | None]:
-        return {
-            "smoothing": self.smoothing,
-            "off": self.off,
-        }
-
-    def to_json(self) -> dict[str, float | None]:
         return {
             "smoothing": self.smoothing,
         }
 
     @classmethod
     def from_dict(cls, data: dict[str, float | bool | None]) -> LowPass:
-        c = cls(
-            smoothing=data["smoothing"],
-        )
-        c.off = data["off"]
-        return c
+        return cls(smoothing=data["smoothing"])
 
     def __repr__(self):
         return f"<LowPass: smoothing={self.smoothing}>"
@@ -40,7 +29,6 @@ class LowPass(FilterMixin):
     @smoothing.setter
     def smoothing(self, v: float | None):
         self._smoothing = v
-        self.off = v is None
 
     @classmethod
     def default(cls) -> LowPass:
@@ -56,4 +44,3 @@ class LowPass(FilterMixin):
 
     def reset(self) -> None:
         self.smoothing = None
-        self.off = True
